==> formmaster-0.1.15.tar.gz: formmaster-0.1.15/src/forms/usyd/personal_info_details.py <==
'''
<div class="sv-form-horizontal">	
							<div class="sv-form-group">
								<label for="IPR_TITL" class="sv-col-md-3 sv-control-label">Title *</label>
								<div class="sv-col-md-4">
									<select name="IPR_TITL" id="IPR_TITL" class="" style="display: none;">
										<option value="">-- Select --</option>
										<option value="MR">Mr</option><option value="MRS">Mrs</option><option value="MISS">Miss</option><option value="MS">Ms</option><option value="DR">Dr</option><option value="ASSOCPROF">Associate Professor</option><option value="PROF">Professor</option><option value="SIR">Sir</option><option value="MX">Mx</option>
									</select><div class="chosen-container chosen-container-single" title="" id="IPR_TITL_chosen" tabindex="-1" style="width: 100%;"><a class="chosen-single">
  <span id="IPR_TITL_chosenspan">Miss</span>
  <div><b></b></div>
</a>
<div class="chosen-drop">
  <div class="chosen-search">
    <input class="chosen-search-input" type="text" autocomplete="off" title="Miss" aria-owns="IPR_TITL_ul" tabindex="0" aria-autocomplete="list" aria-label="Title * search">
  </div>
  <ul class="chosen-results" role="listbox" tabindex="-1" aria-expanded="false" id="IPR_TITL_ul" aria-busy="true" aria-label="Title * options"><li class="active-result result-selected" data-option-array-index="3" id="IPR_TITL0" role="option" tabindex="-1"><em>Miss</em></li></ul>
</div></div>
		<script type="text/javascript">
			// Set the initial value of IPQ_APONSP1
			$('#IPR_TITL').val('');
			sits_chosen_widget('#IPR_TITL', {});
		</script>
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_FNM1" class="sv-col-md-3 sv-control-label">Given name(s) *</label>
	<div class="sv-col-md-4">
		<div class="sv-row">
			<div class="sv-col-xs-12 sv-col-md-4">
				<input name="IPR_FNM1" id="IPR_FNM1" class="sv-form-control" type="text" maxlength="30" value="Jinqiu" placeholder="Given name 1" style="margin-bottom: 5px;" data-gtm-form-interact-field-id="0">
			</div>
			<div class="sv-col-xs-12 sv-col-md-4">
				<input name="IPR_FNM2" id="IPR_FNM2" class="sv-form-control" type="text" maxlength="30" value="" placeholder="Given name 2" style="margin-bottom: 5px;">
			</div>
			<div class="sv-col-xs-12 sv-col-md-4">
				<input name="IPR_FNM3" id="IPR_FNM3" class="sv-form-control" type="text" maxlength="30" value="" placeholder="Given name 3">
			</div>
		</div>
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_SURN" class="sv-col-md-3 sv-control-label">Family name *</label>
	<div class="sv-col-md-4">
		<input name="IPR_SURN" id="IPR_SURN" class="sv-form-control" type="text" maxlength="40" value="Guo" data-gtm-form-interact-field-id="1">
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_FUSD" class="sv-col-md-3 sv-control-label">Known as name *</label>
	<div class="sv-col-md-4">
		<input name="IPR_FUSD" id="IPR_FUSD" class="sv-form-control" type="text" maxlength="40" value="Jinqiu" data-gtm-form-interact-field-id="2">
	</div>
</div>
<div class="sv-form-group">
	<label for="IPQ_APONPRVS" class="sv-col-md-3 sv-control-label">Previous name</label>
	<div class="sv-col-md-4">
		<input name="IPQ_APONPRVS" id="IPQ_APONPRVS" class="sv-form-control" type="text" maxlength="35" value="">
	</div>
</div>
<div class="sv-form-group">
	<label for="IPQ_APONOFFN" class="sv-col-md-3 sv-control-label">Official name *</label>
	<div class="sv-col-md-4">
		<input name="IPQ_APONOFFN" id="IPQ_APONOFFN" class="sv-form-control" type="text" maxlength="100" value="" data-gtm-form-interact-field-id="3">
		<small>Your official name appears on your passport, birth certificate or change of name certificate.</small>
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_GEND" class="sv-col-md-3 sv-control-label">Gender *</label>
	<div class="sv-col-md-4">
		<select name="IPR_GEND" id="IPR_GEND" class="" style="display: none;">
			<option value="">-- Select --</option>
			<option value="M">Male</option>
			<option value="F">Female</option>
			<option value="X">Indeterminate/Intersex/Unspecified</option>
		</select><div class="chosen-container chosen-container-single" title="" id="IPR_GEND_chosen" tabindex="-1" style="width: 100%;"><a class="chosen-single">
  <span id="IPR_GEND_chosenspan">Female</span>
  <div><b></b></div>
</a>
<div class="chosen-drop">
  <div class="chosen-search">
    <input class="chosen-search-input" type="text" autocomplete="off" title="Female" aria-owns="IPR_GEND_ul" tabindex="0" aria-autocomplete="list" aria-label="Gender * search">
  </div>
  <ul class="chosen-results" role="listbox" tabindex="-1" aria-expanded="false" id="IPR_GEND_ul" aria-busy="true" aria-label="Gender * options"><li class="active-result result-selected" data-option-array-index="2" id="IPR_GEND0" role="option" tabindex="-1"><em>F</em>emale</li><li class="active-result" data-option-array-index="3" id="IPR_GEND1" role="option" tabindex="-1">Indeterminate/Intersex/Unspeci<em>f</em>ied</li></ul>
</div></div>
			<script type="text/javascript">
				// Set the initial value of IPQ_APONSP1
				$('#IPR_GEND').val('');
				sits_chosen_widget('#IPR_GEND', {});
			</script>
		</div>
	</div>
	<div class="sv-form-group">
		<label for="IPR_DOB" class="sv-col-md-3 sv-control-label">Date of birth (dd/mm/yyyy) *</label>
		<div class="sv-col-md-4">
			<div class="sv-input-group">
				<input name="IPR_DOB" id="IPR_DOB" class="sv-form-control hasDatepicker" type="text" maxlength="35" value="01/01/2000">
				<span class="sv-input-group-addon"><img class="ui-datepicker-trigger" src="../images/si_calendar.gif" alt="..." title="..." role="button" tabindex="0"></span>
			</div>
		</div>
	</div>
</div>
'''

import re
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from forms.utils.form_utils import set_value_by_id, select_option_by_id

class PersonalInfoDetails:
    def __init__(self, driver, data):
        self.driver = driver
        self.data = data

    def run(self):
        students = self.data
        driver = self.driver
        personal_info = students[-1][0]
        
        # Title selection based on gender (required field)
        gender = personal_info.get('Gender', 'Male')
        title = personal_info.get('Title', '')
        
        if not title:
            # Default titles based on gender if not specified
            if gender.lower() == 'male':
                title = 'Mr'
            elif gender.lower() == 'female':
                title = 'Miss'
            else:
                title = 'Mx'
                
        select_option_by_id(driver, "IPR_TITL", title)
        
        # Given names (first is required)
        given_name = personal_info.get('Given Name', '')
        if not given_name:
            given_name = "DefaultFirstName"
        set_value_by_id(driver, "IPR_FNM1", given_name)
        
        # Optional additional given names
        set_value_by_id(driver, "IPR_FNM2", personal_info.get('Middle Name', ''))
        set_value_by_id(driver, "IPR_FNM3", personal_info.get('Third Name', ''))
        
        # Family name (required)
        family_name = personal_info.get('Family Name', '')
        if not family_name:
            family_name = "DefaultLastName"
        set_value_by_id(driver, "IPR_SURN", family_name)
        
        # Known as name (required) - use given name if not specified
        known_as = personal_info.get('Given Name', given_name)
        set_value_by_id(driver, "IPR_FUSD", known_as)
        
        # Previous name (optional)
        set_value_by_id(driver, "IPQ_APONPRVS", personal_info.get('Previous Name', ''))
        
        # Official name (required) - use full name if not specified
        official_name = f"{personal_info['Given Name']} {personal_info['Family Name']}"
        if not official_name:
            official_name = f"{given_name} {family_name}"
        set_value_by_id(driver, "IPQ_APONOFFN", official_name)
        
        # Gender selection (required)
        select_option_by_id(driver, "IPR_GEND", gender)
        
        # Date of birth (required)
        dob = personal_info.get('DOB', '')
        if not dob:
            # Try alternative keys for DOB
            dob_keys = ['Date of Birth', 'DOB (dd/mm/yyyy)', 'Birth Date', 'Birthday']
            for key in dob_keys:
                if key in personal_info:
                    dob = personal_info[key]
                    break
                    
        if not dob:
            dob = "01/01/2000"  # Default DOB if not found
            
        set_value_by_id(driver, "IPR_DOB", dob)
    
    # Methods removed as they're now imported from form_utils.py

==> formmaster-0.1.18.tar.gz: formmaster-0.1.18/src/forms/usyd/personal_info_details.py <==
'''
<div class="sv-form-horizontal">	
							<div class="sv-form-group">
								<label for="IPR_TITL" class="sv-col-md-3 sv-control-label">Title *</label>
								<div class="sv-col-md-4">
									<select name="IPR_TITL" id="IPR_TITL" class="" style="display: none;">
										<option value="">-- Select --</option>
										<option value="MR">Mr</option><option value="MRS">Mrs</option><option value="MISS">Miss</option><option value="MS">Ms</option><option value="DR">Dr</option><option value="ASSOCPROF">Associate Professor</option><option value="PROF">Professor</option><option value="SIR">Sir</option><option value="MX">Mx</option>
									</select><div class="chosen-container chosen-container-single" title="" id="IPR_TITL_chosen" tabindex="-1" style="width: 100%;"><a class="chosen-single">
  <span id="IPR_TITL_chosenspan">Miss</span>
  <div><b></b></div>
</a>
<div class="chosen-drop">
  <div class="chosen-search">
    <input class="chosen-search-input" type="text" autocomplete="off" title="Miss" aria-owns="IPR_TITL_ul" tabindex="0" aria-autocomplete="list" aria-label="Title * search">
  </div>
  <ul class="chosen-results" role="listbox" tabindex="-1" aria-expanded="false" id="IPR_TITL_ul" aria-busy="true" aria-label="Title * options"><li class="active-result result-selected" data-option-array-index="3" id="IPR_TITL0" role="option" tabindex="-1"><em>Miss</em></li></ul>
</div></div>
		<script type="text/javascript">
			// Set the initial value of IPQ_APONSP1
			$('#IPR_TITL').val('');
			sits_chosen_widget('#IPR_TITL', {});
		</script>
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_FNM1" class="sv-col-md-3 sv-control-label">Given name(s) *</label>
	<div class="sv-col-md-4">
		<div class="sv-row">
			<div class="sv-col-xs-12 sv-col-md-4">
				<input name="IPR_FNM1" id="IPR_FNM1" class="sv-form-control" type="text" maxlength="30" value="Jinqiu" placeholder="Given name 1" style="margin-bottom: 5px;" data-gtm-form-interact-field-id="0">
			</div>
			<div class="sv-col-xs-12 sv-col-md-4">
				<input name="IPR_FNM2" id="IPR_FNM2" class="sv-form-control" type="text" maxlength="30" value="" placeholder="Given name 2" style="margin-bottom: 5px;">
			</div>
			<div class="sv-col-xs-12 sv-col-md-4">
				<input name="IPR_FNM3" id="IPR_FNM3" class="sv-form-control" type="text" maxlength="30" value="" placeholder="Given name 3">
			</div>
		</div>
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_SURN" class="sv-col-md-3 sv-control-label">Family name *</label>
	<div class="sv-col-md-4">
		<input name="IPR_SURN" id="IPR_SURN" class="sv-form-control" type="text" maxlength="40" value="Guo" data-gtm-form-interact-field-id="1">
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_FUSD" class="sv-col-md-3 sv-control-label">Known as name *</label>
	<div class="sv-col-md-4">
		<input name="IPR_FUSD" id="IPR_FUSD" class="sv-form-control" type="text" maxlength="40" value="Jinqiu" data-gtm-form-interact-field-id="2">
	</div>
</div>
<div class="sv-form-group">
	<label for="IPQ_APONPRVS" class="sv-col-md-3 sv-control-label">Previous name</label>
	<div class="sv-col-md-4">
		<input name="IPQ_APONPRVS" id="IPQ_APONPRVS" class="sv-form-control" type="text" maxlength="35" value="">
	</div>
</div>
<div class="sv-form-group">
	<label for="IPQ_APONOFFN" class="sv-col-md-3 sv-control-label">Official name *</label>
	<div class="sv-col-md-4">
		<input name="IPQ_APONOFFN" id="IPQ_APONOFFN" class="sv-form-control" type="text" maxlength="100" value="" data-gtm-form-interact-field-id="3">
		<small>Your official name appears on your passport, birth certificate or change of name certificate.</small>
	</div>
</div>
<div class="sv-form-group">
	<label for="IPR_GEND" class="sv-col-md-3 sv-control-label">Gender *</label>
	<div class="sv-col-md-4">
		<select name="IPR_GEND" id="IPR_GEND" class="" style="display: none;">
			<option value="">-- Select --</option>
			<option value="M">Male</option>
			<option value="F">Female</option>
			<option value="X">Indeterminate/Intersex/Unspecified</option>
		</select><div class="chosen-container chosen-container-single" title="" id="IPR_GEND_chosen" tabindex="-1" style="width: 100%;"><a class="chosen-single">
  <span id="IPR_GEND_chosenspan">Female</span>
  <div><b></b></div>
</a>
<div class="chosen-drop">
  <div class="chosen-search">
    <input class="chosen-search-input" type="text" autocomplete="off" title="Female" aria-owns="IPR_GEND_ul" tabindex="0" aria-autocomplete="list" aria-label="Gender * search">
  </div>
  <ul class="chosen-results" role="listbox" tabindex="-1" aria-expanded="false" id="IPR_GEND_ul" aria-busy="true" aria-label="Gender * options"><li class="active-result result-selected" data-option-array-index="2" id="IPR_GEND0" role="option" tabindex="-1"><em>F</em>emale</li><li class="active-result" data-option-array-index="3" id="IPR_GEND1" role="option" tabindex="-1">Indeterminate/Intersex/Unspeci<em>f</em>ied</li></ul>
</div></div>
			<script type="text/javascript">
				// Set the initial value of IPQ_APONSP1
				$('#IPR_GEND').val('');
				sits_chosen_widget('#IPR_GEND', {});
			</script>
		</div>
	</div>
	<div class="sv-form-group">
		<label for="IPR_DOB" class="sv-col-md-3 sv-control-label">Date of birth (dd/mm/yyyy) *</label>
		<div class="sv-col-md-4">
			<div class="sv-input-group">
				<input name="IPR_DOB" id="IPR_DOB" class="sv-form-control hasDatepicker" type="text" maxlength="35" value="01/01/2000">
				<span class="sv-input-group-addon"><img class="ui-datepicker-trigger" src="../images/si_calendar.gif" alt="..." title="..." role="button" tabindex="0"></span>
			</div>
		</div>
	</div>
</div>
'''

import re
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from forms.utils.form_utils import set_value_by_id, select_option_by_id, select_chosen_option_by_id
from logger import get_logger

class PersonalInfoDetails:
    def __init__(self, driver, data):
        self.driver = driver
        self.data = data
        self.logger = get_logger('PersonalInfoDetails')

    def run(self):
        students = self.data
        driver = self.driver
        personal_info = students[-1][0]
        
        # Title selection based on gender (required field)
        gender = personal_info.get('Gender', 'Male')
        # Default titles based on gender if not specified
        if gender.lower() == 'male' or gender.lower() == 'm':
            title = 'Mr'
        elif gender.lower() == 'female' or gender.lower() == 'f':
            title = 'Miss'
        else:
            title = 'Mx'
                
        #select_option_by_id(driver, "IPR_TITL", title)
        select_chosen_option_by_id(driver, "IPR_TITL", title)
        self.logger.info(f"Selected title: {title}")

        # Given names (first is required)
        given_name = personal_info.get('Given Name', '')
        if not given_name:
            given_name = "DefaultFirstName"
        set_value_by_id(driver, "IPR_FNM1", given_name)
        
        # Optional additional given names
        set_value_by_id(driver, "IPR_FNM2", personal_info.get('Middle Name', ''))
        set_value_by_id(driver, "IPR_FNM3", personal_info.get('Third Name', ''))
        
        # Family name (required)
        family_name = personal_info.get('Family Name', '')
        if not family_name:
            family_name = "DefaultLastName"
        set_value_by_id(driver, "IPR_SURN", family_name)
        
        # Known as name (required) - use given name if not specified
        known_as = personal_info.get('Given Name', given_name)
        set_value_by_id(driver, "IPR_FUSD", known_as)
        
        # Previous name (optional)
        set_value_by_id(driver, "IPQ_APONPRVS", personal_info.get('Previous Name', ''))
        
        # Official name (required) - use full name if not specified
        set_value_by_id(driver, "IPQ_APONOFFN", f"{given_name} {family_name}")
        self.logger.info(f"Official name: {given_name} {family_name}")
        
        # Gender selection (required)
        select_option_by_id(driver, "IPR_GEND", gender)
        self.logger.info(f"Gender: {gender}")
        
        # Date of birth (required)
        dob = personal_info.get('DOB', '')
        if not dob:
            # Try alternative keys for DOB
            dob_keys = ['Date of Birth', 'DOB (dd/mm/yyyy)', 'Birth Date', 'Birthday']
            for key in dob_keys:
                if key in personal_info:
                    dob = personal_info[key]
                    break
                    
        if not dob:
            dob = "01/01/2000"  # Default DOB if not found
            
        set_value_by_id(driver, "IPR_DOB", dob)
    
    # Methods removed as they're now imported from form_utils.py
